@@ -50,10 +50,45 @@ class ExecutionsAsyncClient:
 
     execution_path = staticmethod(ExecutionsClient.execution_path)
     parse_execution_path = staticmethod(ExecutionsClient.parse_execution_path)
+    workflow_path = staticmethod(ExecutionsClient.workflow_path)
+    parse_workflow_path = staticmethod(ExecutionsClient.parse_workflow_path)
 
+    common_billing_account_path = staticmethod(
+        ExecutionsClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        ExecutionsClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(ExecutionsClient.common_folder_path)
+    parse_common_folder_path = staticmethod(ExecutionsClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(ExecutionsClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        ExecutionsClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(ExecutionsClient.common_project_path)
+    parse_common_project_path = staticmethod(ExecutionsClient.parse_common_project_path)
+
+    common_location_path = staticmethod(ExecutionsClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        ExecutionsClient.parse_common_location_path
+    )
+
+    from_service_account_info = ExecutionsClient.from_service_account_info
     from_service_account_file = ExecutionsClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> ExecutionsTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            ExecutionsTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(ExecutionsClient).get_transport_class, type(ExecutionsClient)
     )
@@ -122,7 +157,7 @@ class ExecutionsAsyncClient:
         first).
 
         Args:
-            request (:class:`~.executions.ListExecutionsRequest`):
+            request (:class:`google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest`):
                 The request object. Request for the
                 [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
                 method.
@@ -131,6 +166,7 @@ class ExecutionsAsyncClient:
                 which the executions should be listed.
                 Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -142,10 +178,10 @@ class ExecutionsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListExecutionsAsyncPager:
+            google.cloud.workflows.executions_v1beta.services.executions.pagers.ListExecutionsAsyncPager:
                 Response for the
-                [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
-                method.
+                   [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
+                   method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -154,7 +190,8 @@ class ExecutionsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -208,7 +245,7 @@ class ExecutionsAsyncClient:
         the given workflow.
 
         Args:
-            request (:class:`~.executions.CreateExecutionRequest`):
+            request (:class:`google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest`):
                 The request object. Request for the
                 [CreateExecution][google.cloud.workflows.executions.v1beta.Executions.CreateExecution]
                 method.
@@ -219,10 +256,11 @@ class ExecutionsAsyncClient:
                 projects/{project}/locations/{location}/workflows/{workflow}
                 The latest revision of the workflow will
                 be used.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            execution (:class:`~.executions.Execution`):
+            execution (:class:`google.cloud.workflows.executions_v1beta.types.Execution`):
                 Required. Execution to be created.
                 This corresponds to the ``execution`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -235,7 +273,7 @@ class ExecutionsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
@@ -243,7 +281,8 @@ class ExecutionsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, execution]):
+        has_flattened_params = any([parent, execution])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -291,7 +330,7 @@ class ExecutionsAsyncClient:
         r"""Returns an execution of the given name.
 
         Args:
-            request (:class:`~.executions.GetExecutionRequest`):
+            request (:class:`google.cloud.workflows.executions_v1beta.types.GetExecutionRequest`):
                 The request object. Request for the
                 [GetExecution][google.cloud.workflows.executions.v1beta.Executions.GetExecution]
                 method.
@@ -299,6 +338,7 @@ class ExecutionsAsyncClient:
                 Required. Name of the execution to be
                 retrieved. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -310,7 +350,7 @@ class ExecutionsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
@@ -318,7 +358,8 @@ class ExecutionsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -364,7 +405,7 @@ class ExecutionsAsyncClient:
         r"""Cancels an execution of the given name.
 
         Args:
-            request (:class:`~.executions.CancelExecutionRequest`):
+            request (:class:`google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest`):
                 The request object. Request for the
                 [CancelExecution][google.cloud.workflows.executions.v1beta.Executions.CancelExecution]
                 method.
@@ -372,6 +413,7 @@ class ExecutionsAsyncClient:
                 Required. Name of the execution to be
                 cancelled. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -383,7 +425,7 @@ class ExecutionsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
@@ -391,7 +433,8 @@ class ExecutionsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
