@@ -19,10 +19,10 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Sequence, Tuple, Type, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core import client_options as client_options_lib  # type: ignore
 from google.api_core import exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
@@ -112,6 +112,22 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            ExecutionsClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -124,7 +140,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            ExecutionsClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -132,6 +148,15 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> ExecutionsTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            ExecutionsTransport: The transport used by the client instance.
+        """
+        return self._transport
+
     @staticmethod
     def execution_path(
         project: str, location: str, workflow: str, execution: str,
@@ -150,12 +175,87 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def workflow_path(project: str, location: str, workflow: str,) -> str:
+        """Return a fully-qualified workflow string."""
+        return "projects/{project}/locations/{location}/workflows/{workflow}".format(
+            project=project, location=location, workflow=workflow,
+        )
+
+    @staticmethod
+    def parse_workflow_path(path: str) -> Dict[str, str]:
+        """Parse a workflow path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/workflows/(?P<workflow>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Return a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Return a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Return a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Return a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Return a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
-        transport: Union[str, ExecutionsTransport] = None,
-        client_options: ClientOptions = None,
+        credentials: Optional[credentials.Credentials] = None,
+        transport: Union[str, ExecutionsTransport, None] = None,
+        client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the executions client.
@@ -166,11 +266,11 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.ExecutionsTransport]): The
+            transport (Union[str, ExecutionsTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (ClientOptions): Custom options for the client. It
-                won't take effect if a ``transport`` instance is provided.
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
@@ -185,10 +285,10 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 not provided, the default SSL client certificate will be used if
                 present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                 set, no client certificate will be used.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -196,9 +296,9 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 creation failed for any reason.
         """
         if isinstance(client_options, dict):
-            client_options = ClientOptions.from_dict(client_options)
+            client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
-            client_options = ClientOptions.ClientOptions()
+            client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
         use_client_cert = bool(
@@ -283,15 +383,16 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         first).
 
         Args:
-            request (:class:`~.executions.ListExecutionsRequest`):
+            request (google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest):
                 The request object. Request for the
                 [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
                 method.
-            parent (:class:`str`):
+            parent (str):
                 Required. Name of the workflow for
                 which the executions should be listed.
                 Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -303,10 +404,10 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListExecutionsPager:
+            google.cloud.workflows.executions_v1beta.services.executions.pagers.ListExecutionsPager:
                 Response for the
-                [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
-                method.
+                   [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
+                   method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -371,21 +472,22 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         the given workflow.
 
         Args:
-            request (:class:`~.executions.CreateExecutionRequest`):
+            request (google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest):
                 The request object. Request for the
                 [CreateExecution][google.cloud.workflows.executions.v1beta.Executions.CreateExecution]
                 method.
-            parent (:class:`str`):
+            parent (str):
                 Required. Name of the workflow for
                 which an execution should be created.
                 Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
                 The latest revision of the workflow will
                 be used.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            execution (:class:`~.executions.Execution`):
+            execution (google.cloud.workflows.executions_v1beta.types.Execution):
                 Required. Execution to be created.
                 This corresponds to the ``execution`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -398,7 +500,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
@@ -456,14 +558,15 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         r"""Returns an execution of the given name.
 
         Args:
-            request (:class:`~.executions.GetExecutionRequest`):
+            request (google.cloud.workflows.executions_v1beta.types.GetExecutionRequest):
                 The request object. Request for the
                 [GetExecution][google.cloud.workflows.executions.v1beta.Executions.GetExecution]
                 method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the execution to be
                 retrieved. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -475,7 +578,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
@@ -531,14 +634,15 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         r"""Cancels an execution of the given name.
 
         Args:
-            request (:class:`~.executions.CancelExecutionRequest`):
+            request (google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest):
                 The request object. Request for the
                 [CancelExecution][google.cloud.workflows.executions.v1beta.Executions.CancelExecution]
                 method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the execution to be
                 cancelled. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -550,7 +654,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.executions.Execution:
+            google.cloud.workflows.executions_v1beta.types.Execution:
                 A running instance of a
                 [Workflow][google.cloud.workflows.v1beta.Workflow].
 
