@@ -22,9 +22,9 @@ from .executions import (
     CreateExecutionRequest,
     GetExecutionRequest,
     CancelExecutionRequest,
+    ExecutionView,
 )
 
-
 __all__ = (
     "Execution",
     "ListExecutionsRequest",
@@ -32,4 +32,5 @@ __all__ = (
     "CreateExecutionRequest",
     "GetExecutionRequest",
     "CancelExecutionRequest",
+    "ExecutionView",
 )
