@@ -28,8 +28,8 @@ from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.api_core import operation
-from google.api_core import operation_async
+from google.api_core import operation  # type: ignore
+from google.api_core import operation_async  # type: ignore
 from google.cloud.workflows_v1beta.services.workflows import pagers
 from google.cloud.workflows_v1beta.types import workflows
 from google.protobuf import empty_pb2 as empty  # type: ignore
@@ -55,9 +55,42 @@ class WorkflowsAsyncClient:
     workflow_path = staticmethod(WorkflowsClient.workflow_path)
     parse_workflow_path = staticmethod(WorkflowsClient.parse_workflow_path)
 
+    common_billing_account_path = staticmethod(
+        WorkflowsClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        WorkflowsClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(WorkflowsClient.common_folder_path)
+    parse_common_folder_path = staticmethod(WorkflowsClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(WorkflowsClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        WorkflowsClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(WorkflowsClient.common_project_path)
+    parse_common_project_path = staticmethod(WorkflowsClient.parse_common_project_path)
+
+    common_location_path = staticmethod(WorkflowsClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        WorkflowsClient.parse_common_location_path
+    )
+
+    from_service_account_info = WorkflowsClient.from_service_account_info
     from_service_account_file = WorkflowsClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> WorkflowsTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            WorkflowsTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(WorkflowsClient).get_transport_class, type(WorkflowsClient)
     )
@@ -123,7 +156,7 @@ class WorkflowsAsyncClient:
         The default order is not specified.
 
         Args:
-            request (:class:`~.workflows.ListWorkflowsRequest`):
+            request (:class:`google.cloud.workflows_v1beta.types.ListWorkflowsRequest`):
                 The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
                 method.
@@ -132,6 +165,7 @@ class WorkflowsAsyncClient:
                 which the workflows should be listed.
                 Format:
                 projects/{project}/locations/{location}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -143,10 +177,10 @@ class WorkflowsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListWorkflowsAsyncPager:
+            google.cloud.workflows_v1beta.services.workflows.pagers.ListWorkflowsAsyncPager:
                 Response for the
-                [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
-                method.
+                   [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
+                   method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -155,7 +189,8 @@ class WorkflowsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -207,7 +242,7 @@ class WorkflowsAsyncClient:
         r"""Gets details of a single Workflow.
 
         Args:
-            request (:class:`~.workflows.GetWorkflowRequest`):
+            request (:class:`google.cloud.workflows_v1beta.types.GetWorkflowRequest`):
                 The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1beta.Workflows.GetWorkflow]
                 method.
@@ -215,6 +250,7 @@ class WorkflowsAsyncClient:
                 Required. Name of the workflow which
                 information should be retrieved. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -226,7 +262,7 @@ class WorkflowsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.workflows.Workflow:
+            google.cloud.workflows_v1beta.types.Workflow:
                 Workflow program to be executed by
                 Workflows.
 
@@ -234,7 +270,8 @@ class WorkflowsAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -285,7 +322,7 @@ class WorkflowsAsyncClient:
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
         Args:
-            request (:class:`~.workflows.CreateWorkflowRequest`):
+            request (:class:`google.cloud.workflows_v1beta.types.CreateWorkflowRequest`):
                 The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1beta.Workflows.CreateWorkflow]
                 method.
@@ -294,10 +331,11 @@ class WorkflowsAsyncClient:
                 which the workflow should be created.
                 Format:
                 projects/{project}/locations/{location}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            workflow (:class:`~.workflows.Workflow`):
+            workflow (:class:`google.cloud.workflows_v1beta.types.Workflow`):
                 Required. Workflow to be created.
                 This corresponds to the ``workflow`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -314,6 +352,7 @@ class WorkflowsAsyncClient:
                 -  Must be unique within the customer project and
                    location.
 
+
                 This corresponds to the ``workflow_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -325,18 +364,19 @@ class WorkflowsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.workflows.Workflow``: Workflow program to be
-                executed by Workflows.
+                :class:`google.cloud.workflows_v1beta.types.Workflow`
+                Workflow program to be executed by Workflows.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, workflow, workflow_id]):
+        has_flattened_params = any([parent, workflow, workflow_id])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -396,7 +436,7 @@ class WorkflowsAsyncClient:
         executions of the workflow.
 
         Args:
-            request (:class:`~.workflows.DeleteWorkflowRequest`):
+            request (:class:`google.cloud.workflows_v1beta.types.DeleteWorkflowRequest`):
                 The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1beta.Workflows.DeleteWorkflow]
                 method.
@@ -404,6 +444,7 @@ class WorkflowsAsyncClient:
                 Required. Name of the workflow to be
                 deleted. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -415,30 +456,29 @@ class WorkflowsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -498,19 +538,20 @@ class WorkflowsAsyncClient:
         used in new workflow executions.
 
         Args:
-            request (:class:`~.workflows.UpdateWorkflowRequest`):
+            request (:class:`google.cloud.workflows_v1beta.types.UpdateWorkflowRequest`):
                 The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1beta.Workflows.UpdateWorkflow]
                 method.
-            workflow (:class:`~.workflows.Workflow`):
+            workflow (:class:`google.cloud.workflows_v1beta.types.Workflow`):
                 Required. Workflow to be updated.
                 This corresponds to the ``workflow`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 List of fields to be updated. If not
                 present, the entire workflow will be
                 updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -522,18 +563,19 @@ class WorkflowsAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.workflows.Workflow``: Workflow program to be
-                executed by Workflows.
+                :class:`google.cloud.workflows_v1beta.types.Workflow`
+                Workflow program to be executed by Workflows.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([workflow, update_mask]):
+        has_flattened_params = any([workflow, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
