@@ -19,10 +19,10 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Sequence, Tuple, Type, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core import client_options as client_options_lib  # type: ignore
 from google.api_core import exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
@@ -32,8 +32,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.api_core import operation
-from google.api_core import operation_async
+from google.api_core import operation  # type: ignore
+from google.api_core import operation_async  # type: ignore
 from google.cloud.workflows_v1beta.services.workflows import pagers
 from google.cloud.workflows_v1beta.types import workflows
 from google.protobuf import empty_pb2 as empty  # type: ignore
@@ -116,6 +116,22 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WorkflowsClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -128,7 +144,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            WorkflowsClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -136,6 +152,15 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> WorkflowsTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            WorkflowsTransport: The transport used by the client instance.
+        """
+        return self._transport
+
     @staticmethod
     def workflow_path(project: str, location: str, workflow: str,) -> str:
         """Return a fully-qualified workflow string."""
@@ -152,12 +177,71 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Return a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Return a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Return a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Return a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Return a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
-        transport: Union[str, WorkflowsTransport] = None,
-        client_options: ClientOptions = None,
+        credentials: Optional[credentials.Credentials] = None,
+        transport: Union[str, WorkflowsTransport, None] = None,
+        client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the workflows client.
@@ -168,11 +252,11 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.WorkflowsTransport]): The
+            transport (Union[str, WorkflowsTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (ClientOptions): Custom options for the client. It
-                won't take effect if a ``transport`` instance is provided.
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
@@ -187,10 +271,10 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 not provided, the default SSL client certificate will be used if
                 present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                 set, no client certificate will be used.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -198,9 +282,9 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 creation failed for any reason.
         """
         if isinstance(client_options, dict):
-            client_options = ClientOptions.from_dict(client_options)
+            client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
-            client_options = ClientOptions.ClientOptions()
+            client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
         use_client_cert = bool(
@@ -282,15 +366,16 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         The default order is not specified.
 
         Args:
-            request (:class:`~.workflows.ListWorkflowsRequest`):
+            request (google.cloud.workflows_v1beta.types.ListWorkflowsRequest):
                 The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
                 method.
-            parent (:class:`str`):
+            parent (str):
                 Required. Project and location from
                 which the workflows should be listed.
                 Format:
                 projects/{project}/locations/{location}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -302,10 +387,10 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListWorkflowsPager:
+            google.cloud.workflows_v1beta.services.workflows.pagers.ListWorkflowsPager:
                 Response for the
-                [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
-                method.
+                   [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
+                   method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -368,14 +453,15 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         r"""Gets details of a single Workflow.
 
         Args:
-            request (:class:`~.workflows.GetWorkflowRequest`):
+            request (google.cloud.workflows_v1beta.types.GetWorkflowRequest):
                 The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1beta.Workflows.GetWorkflow]
                 method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the workflow which
                 information should be retrieved. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -387,7 +473,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.workflows.Workflow:
+            google.cloud.workflows_v1beta.types.Workflow:
                 Workflow program to be executed by
                 Workflows.
 
@@ -448,24 +534,25 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
         Args:
-            request (:class:`~.workflows.CreateWorkflowRequest`):
+            request (google.cloud.workflows_v1beta.types.CreateWorkflowRequest):
                 The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1beta.Workflows.CreateWorkflow]
                 method.
-            parent (:class:`str`):
+            parent (str):
                 Required. Project and location in
                 which the workflow should be created.
                 Format:
                 projects/{project}/locations/{location}
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            workflow (:class:`~.workflows.Workflow`):
+            workflow (google.cloud.workflows_v1beta.types.Workflow):
                 Required. Workflow to be created.
                 This corresponds to the ``workflow`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            workflow_id (:class:`str`):
+            workflow_id (str):
                 Required. The ID of the workflow to be created. It has
                 to fulfill the following requirements:
 
@@ -477,6 +564,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 -  Must be unique within the customer project and
                    location.
 
+
                 This corresponds to the ``workflow_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -488,12 +576,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.workflows.Workflow``: Workflow program to be
-                executed by Workflows.
+                :class:`google.cloud.workflows_v1beta.types.Workflow`
+                Workflow program to be executed by Workflows.
 
         """
         # Create or coerce a protobuf request object.
@@ -561,14 +649,15 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         executions of the workflow.
 
         Args:
-            request (:class:`~.workflows.DeleteWorkflowRequest`):
+            request (google.cloud.workflows_v1beta.types.DeleteWorkflowRequest):
                 The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1beta.Workflows.DeleteWorkflow]
                 method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the workflow to be
                 deleted. Format:
                 projects/{project}/locations/{location}/workflows/{workflow}
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -580,24 +669,22 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -665,19 +752,20 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         used in new workflow executions.
 
         Args:
-            request (:class:`~.workflows.UpdateWorkflowRequest`):
+            request (google.cloud.workflows_v1beta.types.UpdateWorkflowRequest):
                 The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1beta.Workflows.UpdateWorkflow]
                 method.
-            workflow (:class:`~.workflows.Workflow`):
+            workflow (google.cloud.workflows_v1beta.types.Workflow):
                 Required. Workflow to be updated.
                 This corresponds to the ``workflow`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 List of fields to be updated. If not
                 present, the entire workflow will be
                 updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -689,12 +777,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.workflows.Workflow``: Workflow program to be
-                executed by Workflows.
+                :class:`google.cloud.workflows_v1beta.types.Workflow`
+                Workflow program to be executed by Workflows.
 
         """
         # Create or coerce a protobuf request object.
