@@ -86,7 +86,20 @@ def test__get_default_mtls_endpoint():
     assert ExecutionsClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [ExecutionsClient, ExecutionsAsyncClient])
+def test_executions_client_from_service_account_info():
+    creds = credentials.AnonymousCredentials()
+    with mock.patch.object(
+        service_account.Credentials, "from_service_account_info"
+    ) as factory:
+        factory.return_value = creds
+        info = {"valid": True}
+        client = ExecutionsClient.from_service_account_info(info)
+        assert client.transport._credentials == creds
+
+        assert client.transport._host == "workflowexecutions.googleapis.com:443"
+
+
+@pytest.mark.parametrize("client_class", [ExecutionsClient, ExecutionsAsyncClient,])
 def test_executions_client_from_service_account_file(client_class):
     creds = credentials.AnonymousCredentials()
     with mock.patch.object(
@@ -94,17 +107,20 @@ def test_executions_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "workflowexecutions.googleapis.com:443"
+        assert client.transport._host == "workflowexecutions.googleapis.com:443"
 
 
 def test_executions_client_get_transport_class():
     transport = ExecutionsClient.get_transport_class()
-    assert transport == transports.ExecutionsGrpcTransport
+    available_transports = [
+        transports.ExecutionsGrpcTransport,
+    ]
+    assert transport in available_transports
 
     transport = ExecutionsClient.get_transport_class("grpc")
     assert transport == transports.ExecutionsGrpcTransport
@@ -443,7 +459,7 @@ def test_list_executions(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_executions), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.ListExecutionsResponse(
             next_page_token="next_page_token_value",
@@ -458,6 +474,7 @@ def test_list_executions(
         assert args[0] == executions.ListExecutionsRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, pagers.ListExecutionsPager)
 
     assert response.next_page_token == "next_page_token_value"
@@ -468,19 +485,19 @@ def test_list_executions_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_list_executions_async(transport: str = "grpc_asyncio"):
+async def test_list_executions_async(
+    transport: str = "grpc_asyncio", request_type=executions.ListExecutionsRequest
+):
     client = ExecutionsAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = executions.ListExecutionsRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_executions), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.ListExecutionsResponse(next_page_token="next_page_token_value",)
@@ -492,7 +509,7 @@ async def test_list_executions_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == executions.ListExecutionsRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, pagers.ListExecutionsAsyncPager)
@@ -500,6 +517,11 @@ async def test_list_executions_async(transport: str = "grpc_asyncio"):
     assert response.next_page_token == "next_page_token_value"
 
 
+@pytest.mark.asyncio
+async def test_list_executions_async_from_dict():
+    await test_list_executions_async(request_type=dict)
+
+
 def test_list_executions_field_headers():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -509,7 +531,7 @@ def test_list_executions_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_executions), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         call.return_value = executions.ListExecutionsResponse()
 
         client.list_executions(request)
@@ -534,9 +556,7 @@ async def test_list_executions_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_executions), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.ListExecutionsResponse()
         )
@@ -557,7 +577,7 @@ def test_list_executions_flattened():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_executions), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.ListExecutionsResponse()
 
@@ -589,9 +609,7 @@ async def test_list_executions_flattened_async():
     client = ExecutionsAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.list_executions), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.ListExecutionsResponse()
 
@@ -626,7 +644,7 @@ def test_list_executions_pager():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials,)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_executions), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             executions.ListExecutionsResponse(
@@ -664,7 +682,7 @@ def test_list_executions_pages():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials,)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.list_executions), "__call__") as call:
+    with mock.patch.object(type(client.transport.list_executions), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             executions.ListExecutionsResponse(
@@ -695,9 +713,7 @@ async def test_list_executions_async_pager():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.list_executions),
-        "__call__",
-        new_callable=mock.AsyncMock,
+        type(client.transport.list_executions), "__call__", new_callable=mock.AsyncMock
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -734,9 +750,7 @@ async def test_list_executions_async_pages():
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
-        type(client._client._transport.list_executions),
-        "__call__",
-        new_callable=mock.AsyncMock,
+        type(client.transport.list_executions), "__call__", new_callable=mock.AsyncMock
     ) as call:
         # Set the response to a series of pages.
         call.side_effect = (
@@ -776,9 +790,7 @@ def test_create_execution(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution(
             name="name_value",
@@ -797,6 +809,7 @@ def test_create_execution(
         assert args[0] == executions.CreateExecutionRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, executions.Execution)
 
     assert response.name == "name_value"
@@ -815,19 +828,19 @@ def test_create_execution_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_create_execution_async(transport: str = "grpc_asyncio"):
+async def test_create_execution_async(
+    transport: str = "grpc_asyncio", request_type=executions.CreateExecutionRequest
+):
     client = ExecutionsAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = executions.CreateExecutionRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution(
@@ -845,7 +858,7 @@ async def test_create_execution_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == executions.CreateExecutionRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, executions.Execution)
@@ -861,6 +874,11 @@ async def test_create_execution_async(transport: str = "grpc_asyncio"):
     assert response.workflow_revision_id == "workflow_revision_id_value"
 
 
+@pytest.mark.asyncio
+async def test_create_execution_async_from_dict():
+    await test_create_execution_async(request_type=dict)
+
+
 def test_create_execution_field_headers():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -870,9 +888,7 @@ def test_create_execution_field_headers():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         call.return_value = executions.Execution()
 
         client.create_execution(request)
@@ -897,9 +913,7 @@ async def test_create_execution_field_headers_async():
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution()
         )
@@ -920,9 +934,7 @@ def test_create_execution_flattened():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -960,9 +972,7 @@ async def test_create_execution_flattened_async():
     client = ExecutionsAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.create_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.create_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -1011,7 +1021,7 @@ def test_get_execution(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_execution), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution(
             name="name_value",
@@ -1030,6 +1040,7 @@ def test_get_execution(
         assert args[0] == executions.GetExecutionRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, executions.Execution)
 
     assert response.name == "name_value"
@@ -1048,19 +1059,19 @@ def test_get_execution_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_get_execution_async(transport: str = "grpc_asyncio"):
+async def test_get_execution_async(
+    transport: str = "grpc_asyncio", request_type=executions.GetExecutionRequest
+):
     client = ExecutionsAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = executions.GetExecutionRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution(
@@ -1078,7 +1089,7 @@ async def test_get_execution_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == executions.GetExecutionRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, executions.Execution)
@@ -1094,6 +1105,11 @@ async def test_get_execution_async(transport: str = "grpc_asyncio"):
     assert response.workflow_revision_id == "workflow_revision_id_value"
 
 
+@pytest.mark.asyncio
+async def test_get_execution_async_from_dict():
+    await test_get_execution_async(request_type=dict)
+
+
 def test_get_execution_field_headers():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -1103,7 +1119,7 @@ def test_get_execution_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_execution), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         call.return_value = executions.Execution()
 
         client.get_execution(request)
@@ -1128,9 +1144,7 @@ async def test_get_execution_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution()
         )
@@ -1151,7 +1165,7 @@ def test_get_execution_flattened():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.get_execution), "__call__") as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -1183,9 +1197,7 @@ async def test_get_execution_flattened_async():
     client = ExecutionsAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.get_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.get_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -1228,9 +1240,7 @@ def test_cancel_execution(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution(
             name="name_value",
@@ -1249,6 +1259,7 @@ def test_cancel_execution(
         assert args[0] == executions.CancelExecutionRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, executions.Execution)
 
     assert response.name == "name_value"
@@ -1267,19 +1278,19 @@ def test_cancel_execution_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_cancel_execution_async(transport: str = "grpc_asyncio"):
+async def test_cancel_execution_async(
+    transport: str = "grpc_asyncio", request_type=executions.CancelExecutionRequest
+):
     client = ExecutionsAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = executions.CancelExecutionRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution(
@@ -1297,7 +1308,7 @@ async def test_cancel_execution_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == executions.CancelExecutionRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, executions.Execution)
@@ -1313,6 +1324,11 @@ async def test_cancel_execution_async(transport: str = "grpc_asyncio"):
     assert response.workflow_revision_id == "workflow_revision_id_value"
 
 
+@pytest.mark.asyncio
+async def test_cancel_execution_async_from_dict():
+    await test_cancel_execution_async(request_type=dict)
+
+
 def test_cancel_execution_field_headers():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -1322,9 +1338,7 @@ def test_cancel_execution_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         call.return_value = executions.Execution()
 
         client.cancel_execution(request)
@@ -1349,9 +1363,7 @@ async def test_cancel_execution_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             executions.Execution()
         )
@@ -1372,9 +1384,7 @@ def test_cancel_execution_flattened():
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -1406,9 +1416,7 @@ async def test_cancel_execution_flattened_async():
     client = ExecutionsAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.cancel_execution), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.cancel_execution), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = executions.Execution()
 
@@ -1475,7 +1483,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = ExecutionsClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -1495,7 +1503,7 @@ def test_transport_get_channel():
 
 @pytest.mark.parametrize(
     "transport_class",
-    [transports.ExecutionsGrpcTransport, transports.ExecutionsGrpcAsyncIOTransport],
+    [transports.ExecutionsGrpcTransport, transports.ExecutionsGrpcAsyncIOTransport,],
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
@@ -1508,7 +1516,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = ExecutionsClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.ExecutionsGrpcTransport,)
+    assert isinstance(client.transport, transports.ExecutionsGrpcTransport,)
 
 
 def test_executions_base_transport_error():
@@ -1605,7 +1613,7 @@ def test_executions_host_no_port():
             api_endpoint="workflowexecutions.googleapis.com"
         ),
     )
-    assert client._transport._host == "workflowexecutions.googleapis.com:443"
+    assert client.transport._host == "workflowexecutions.googleapis.com:443"
 
 
 def test_executions_host_with_port():
@@ -1615,11 +1623,11 @@ def test_executions_host_with_port():
             api_endpoint="workflowexecutions.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "workflowexecutions.googleapis.com:8000"
+    assert client.transport._host == "workflowexecutions.googleapis.com:8000"
 
 
 def test_executions_grpc_transport_channel():
-    channel = grpc.insecure_channel("http://localhost/")
+    channel = grpc.secure_channel("http://localhost/", grpc.local_channel_credentials())
 
     # Check that channel is used if provided.
     transport = transports.ExecutionsGrpcTransport(
@@ -1627,10 +1635,11 @@ def test_executions_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_executions_grpc_asyncio_transport_channel():
-    channel = aio.insecure_channel("http://localhost/")
+    channel = aio.secure_channel("http://localhost/", grpc.local_channel_credentials())
 
     # Check that channel is used if provided.
     transport = transports.ExecutionsGrpcAsyncIOTransport(
@@ -1638,6 +1647,7 @@ def test_executions_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -1649,7 +1659,7 @@ def test_executions_transport_channel_mtls_with_client_cert_source(transport_cla
         "grpc.ssl_channel_credentials", autospec=True
     ) as grpc_ssl_channel_cred:
         with mock.patch.object(
-            transport_class, "create_channel", autospec=True
+            transport_class, "create_channel"
         ) as grpc_create_channel:
             mock_ssl_cred = mock.Mock()
             grpc_ssl_channel_cred.return_value = mock_ssl_cred
@@ -1678,8 +1688,13 @@ def test_executions_transport_channel_mtls_with_client_cert_source(transport_cla
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -1694,7 +1709,7 @@ def test_executions_transport_channel_mtls_with_adc(transport_class):
         ssl_credentials=mock.PropertyMock(return_value=mock_ssl_cred),
     ):
         with mock.patch.object(
-            transport_class, "create_channel", autospec=True
+            transport_class, "create_channel"
         ) as grpc_create_channel:
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
@@ -1715,6 +1730,10 @@ def test_executions_transport_channel_mtls_with_adc(transport_class):
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
 
@@ -1746,6 +1765,132 @@ def test_parse_execution_path():
     assert expected == actual
 
 
+def test_workflow_path():
+    project = "winkle"
+    location = "nautilus"
+    workflow = "scallop"
+
+    expected = "projects/{project}/locations/{location}/workflows/{workflow}".format(
+        project=project, location=location, workflow=workflow,
+    )
+    actual = ExecutionsClient.workflow_path(project, location, workflow)
+    assert expected == actual
+
+
+def test_parse_workflow_path():
+    expected = {
+        "project": "abalone",
+        "location": "squid",
+        "workflow": "clam",
+    }
+    path = ExecutionsClient.workflow_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_workflow_path(path)
+    assert expected == actual
+
+
+def test_common_billing_account_path():
+    billing_account = "whelk"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = ExecutionsClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "octopus",
+    }
+    path = ExecutionsClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "oyster"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = ExecutionsClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "nudibranch",
+    }
+    path = ExecutionsClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "cuttlefish"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = ExecutionsClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "mussel",
+    }
+    path = ExecutionsClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "winkle"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = ExecutionsClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "nautilus",
+    }
+    path = ExecutionsClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "scallop"
+    location = "abalone"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = ExecutionsClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "squid",
+        "location": "clam",
+    }
+    path = ExecutionsClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = ExecutionsClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
